@@ -9,6 +9,13 @@ from SDP18py.Generate_initial_solution import initial_solution_random_fit
 
 
 def pareto_ranking(scores1, solns, n):
+	"""
+
+	:param scores1: (lists) of scores, have to correspond with solns index
+	:param solns: (list) population of solutions
+	:param n: (int) max number of ranks wanted
+	:return: (dict) the solutions scores with the diction key as rank and value as scores
+	"""
 	scores = copy.deepcopy(scores1)
 	pareto_rankings = {}
 	pareto_sorted_scores = []
@@ -47,13 +54,18 @@ def pareto_score_soln_sore(scores1, soln):
 
 
 def select_two_parent(ranks, list_scores, list_soln):
+	"""
+	Selection of 2 parents initialization (binary tournament selection method)
+	:param ranks:
+	:param list_scores: (list) of scores
+	:param list_soln:  (list) of population solutions
+	:return: (ndarry) 2 solutions corresponding to the 2 parents
+	"""
 	# crowding distance tournament to select parent
 	crowding_dist = list(calc_crowding_distance(np.array(list_scores)))
 	tournament_size = 16 # multiples of 8
 	tournament_population = random.sample(list_scores, tournament_size)
 	random.shuffle(tournament_population)
-	#tournament_population_indexes = npi.indices(np.array(list_scores), tournament_population)
-	#tournament_crowding_distance = itemgetter(*tournament_population_indexes)(crowding_dist)
 	tournament_population = np.array(tournament_population).reshape(tournament_size//2, 2, 3)
 
 	# tournament starts
@@ -65,7 +77,57 @@ def select_two_parent(ranks, list_scores, list_soln):
 	return list_soln[p1_score_loc], list_soln[p2_score_loc]
 
 
+def tournament(tournament_population, crowding_dist, list_scores):
+	"""
+	Binary tournament selection method, always take better pareto rank. If same rank, use crowding distance as tiebreaker
+	:param tournament_population: (ndarray) tournament population of solutions
+	:param crowding_dist: (list) of crowding distance for each solution in tournament population
+	:param list_scores: (list) of tournament population scores
+	:return: (list) scores of 2 finalist
+	"""
+	tournament_population_list = tournament_population.tolist()  # because we will be removing the ones that lost, better to use list
+	for index, versus in enumerate(tournament_population):
+		score1 = versus[0]
+		score2 = versus[1]
+		if (score1 <= score2).all():  # score 1 dominiates
+			# score2 loses
+			tournament_population_list[index].remove(score2.tolist())
+
+		elif (score2 <= score1).all():  # score 2 dominates
+			# score1 loses
+			tournament_population_list[index].remove(score1.tolist())
+
+		else:  # same rank
+			# based on crowding distance instead
+			index1_ = list_scores.index(score1.tolist())
+			index2_ = list_scores.index(score2.tolist())
+			crowd_score1 = crowding_dist[index1_]
+			crowd_score2 = crowding_dist[index2_]
+			if crowd_score1 > crowd_score2:
+				tournament_population_list[index].remove(score2.tolist())
+			else:
+				tournament_population_list[index].remove(score1.tolist())
+	print(tournament_population_list)
+	random.shuffle(tournament_population_list)
+	new_tournament_pop = np.array(tournament_population_list)
+	new_tournament_pop= new_tournament_pop.reshape(-1, 3)
+	if len(new_tournament_pop) == 2:
+		return new_tournament_pop
+	new_tournament_pop = new_tournament_pop.reshape(len(new_tournament_pop)//2, 2, 3)
+
+	winners = tournament(new_tournament_pop, crowding_dist, list_scores)
+	return winners
+
+
 def GA_crossover(p1, p2, sch_list, empty_schedule):
+	"""
+	For 2 parents to create an offspring which inherits characterisitics of both parents
+	:param p1: (ndarray) parent 1
+	:param p2: (ndarray) parent 2
+	:param sch_list: (list) of surgeries that was to be scheduled
+	:param empty_schedule: (ndarray) the initial schedule before the surgeries were fitted in
+	:return: (ndarray) a child solution
+	"""
 	child = copy.deepcopy(empty_schedule)
 	clashes = []
 	for to_sch in sch_list:
@@ -98,6 +160,15 @@ def GA_crossover(p1, p2, sch_list, empty_schedule):
 
 
 def GA_mutate(child, clashes, MAS_allowed, OT_indexes, day_of_week_indexes):
+	"""
+	Fixes the solution by randomly slotting in clashed slots from parents
+	:param child: (ndarray) solution that was created by crossover
+	:param clashes: (list) of clashes due to crossover
+	:param MAS_allowed: (dict) the MAS restrictions
+	:param OT_indexes: (dict) the OTs in which the index in the array represents
+	:param day_of_week_indexes: (dict) the day of the week in which the index in the array represent
+	:return: (ndarray) 'fixed' child solution
+	"""
 	if len(clashes)==0:
 		return child
 	else:
@@ -119,6 +190,11 @@ def check_if_zero(empty_schedule, locs):
 
 
 def calc_crowding_distance(F):
+	"""
+	Calculate crowding distance of each solution
+	:param F: (list) scores of all solutions
+	:return: (list) crowding distance of each solution
+	"""
 	infinity = 1e+14
 
 	n_points = F.shape[0]
@@ -166,36 +242,3 @@ def calc_crowding_distance(F):
 
 	return crowding
 
-def tournament(tournament_population, crowding_dist, list_scores):
-	tournament_population_list = tournament_population.tolist()  # because we will be removing the ones that lost, better to use list
-	for index, versus in enumerate(tournament_population):
-		score1 = versus[0]
-		score2 = versus[1]
-		if (score1 <= score2).all():  # score 1 dominiates
-			# score2 loses
-			tournament_population_list[index].remove(score2.tolist())
-
-		elif (score2 <= score1).all():  # score 2 dominates
-			# score1 loses
-			tournament_population_list[index].remove(score1.tolist())
-
-		else:  # same rank
-			# based on crowding distance instead
-			index1_ = list_scores.index(score1.tolist())
-			index2_ = list_scores.index(score2.tolist())
-			crowd_score1 = crowding_dist[index1_]
-			crowd_score2 = crowding_dist[index2_]
-			if crowd_score1 > crowd_score2:
-				tournament_population_list[index].remove(score2.tolist())
-			else:
-				tournament_population_list[index].remove(score1.tolist())
-	print(tournament_population_list)
-	random.shuffle(tournament_population_list)
-	new_tournament_pop = np.array(tournament_population_list)
-	new_tournament_pop= new_tournament_pop.reshape(-1, 3)
-	if len(new_tournament_pop) == 2:
-		return new_tournament_pop
-	new_tournament_pop = new_tournament_pop.reshape(len(new_tournament_pop)//2, 2, 3)
-
-	winners = tournament(new_tournament_pop, crowding_dist, list_scores)
-	return winners
\ No newline at end of file
