@@ -298,31 +298,152 @@ def read_csv1(file_path):
             current_schedule[date_index, ot_list.index(row[5]), start_index:end_index] = 2000000 + (
             key_list[position]) * 1000
 
+    # this portion of the code is to add an additional week
     # check current_dates and add 'temp_days' and 'current_dates'
-    if (datetime.strptime(current_dates[-1], '%d/%m/%Y').date()).strftime('%A') == 'Friday':
-        x1 = (datetime.strptime(current_dates[-1], '%d/%m/%Y').date())
-        x2 = temp_days[-1]
-        temp_array = np.zeros([1, 23, 44], dtype=np.int32)
-        dict_elem_count = len(current_dates)
-        mas_week_count = int(day_of_week_index[dict_elem_count - 1].split('y')[1])
-        if mas_week_count != 5:
-            mas_week_count = mas_week_count + 1
-        else:
-            mas_week_count = 1
-        for i in range(3, 8):
-            new_date = x1 + timedelta(days=i)
-            new_datez = new_date.strftime("%d/%m/%Y")
-            new_day = new_date.strftime('%A')
-            current_dates.append(new_datez)
-            new_dayfromnow = x2 + i
-            temp_days.append(new_dayfromnow)
-            current_schedule = np.concatenate([current_schedule, temp_array], axis=0)
-            day_of_week_index[dict_elem_count] = str(new_day) + str(mas_week_count)
-            dict_elem_count = dict_elem_count + 1
+    # if (datetime.strptime(current_dates[-1], '%d/%m/%Y').date()).strftime('%A') == 'Friday':
+    #     x1 = (datetime.strptime(current_dates[-1], '%d/%m/%Y').date())
+    #     x2 = temp_days[-1]
+    #     temp_array = np.zeros([1, 23, 44], dtype=np.int32)
+    #     dict_elem_count = len(current_dates)
+    #     mas_week_count = int(day_of_week_index[dict_elem_count - 1].split('y')[1])
+    #     if mas_week_count != 5:
+    #         mas_week_count = mas_week_count + 1
+    #     else:
+    #         mas_week_count = 1
+    #     for i in range(3, 8):
+    #         new_date = x1 + timedelta(days=i)
+    #         new_datez = new_date.strftime("%d/%m/%Y")
+    #         new_day = new_date.strftime('%A')
+    #         current_dates.append(new_datez)
+    #         new_dayfromnow = x2 + i
+    #         temp_days.append(new_dayfromnow)
+    #         current_schedule = np.concatenate([current_schedule, temp_array], axis=0)
+    #         day_of_week_index[dict_elem_count] = str(new_day) + str(mas_week_count)
+    #         dict_elem_count = dict_elem_count + 1
+    # elif (datetime.strptime(current_dates[-1], '%d/%m/%Y').date()).strftime('%A') == 'Thursday':
+    #     x1 = (datetime.strptime(current_dates[-1], '%d/%m/%Y').date())
+    #     x2 = temp_days[-1]
+    #     temp_array = np.zeros([1, 23, 44], dtype=np.int32)
+    #     dict_elem_count = len(current_dates)
+    #     mas_week_count = int(day_of_week_index[dict_elem_count - 1].split('y')[1])
+    #     i = 1
+    #     new_date = x1 + timedelta(days=i)
+    #     new_datez = new_date.strftime("%d/%m/%Y")
+    #     new_day = new_date.strftime('%A')
+    #     current_dates.append(new_datez)
+    #     new_dayfromnow = x2 + i
+    #     temp_days.append(new_dayfromnow)
+    #     current_schedule = np.concatenate([current_schedule, temp_array], axis=0)
+    #     day_of_week_index[dict_elem_count] = str(new_day) + str(mas_week_count)
+    #     dict_elem_count = dict_elem_count + 1
+    #     if mas_week_count != 5:
+    #         mas_week_count = mas_week_count + 1
+    #     else:
+    #         mas_week_count = 1
+    #     for i in range(4, 8):
+    #         new_date = x1 + timedelta(days=i)
+    #         new_datez = new_date.strftime("%d/%m/%Y")
+    #         new_day = new_date.strftime('%A')
+    #         current_dates.append(new_datez)
+    #         new_dayfromnow = x2 + i
+    #         temp_days.append(new_dayfromnow)
+    #         current_schedule = np.concatenate([current_schedule, temp_array], axis=0)
+    #         day_of_week_index[dict_elem_count] = str(new_day) + str(mas_week_count)
+    #         dict_elem_count = dict_elem_count + 1
+    # elif (datetime.strptime(current_dates[-1], '%d/%m/%Y').date()).strftime('%A') == 'Wednesday':
+    #     x1 = (datetime.strptime(current_dates[-1], '%d/%m/%Y').date())
+    #     x2 = temp_days[-1]
+    #     temp_array = np.zeros([1, 23, 44], dtype=np.int32)
+    #     dict_elem_count = len(current_dates)
+    #     mas_week_count = int(day_of_week_index[dict_elem_count - 1].split('y')[1])
+    #     for i in range(1, 3):
+    #         new_date = x1 + timedelta(days=i)
+    #         new_datez = new_date.strftime("%d/%m/%Y")
+    #         new_day = new_date.strftime('%A')
+    #         current_dates.append(new_datez)
+    #         new_dayfromnow = x2 + i
+    #         temp_days.append(new_dayfromnow)
+    #         current_schedule = np.concatenate([current_schedule, temp_array], axis=0)
+    #         day_of_week_index[dict_elem_count] = str(new_day) + str(mas_week_count)
+    #         dict_elem_count = dict_elem_count + 1
+    #     if mas_week_count != 5:
+    #         mas_week_count = mas_week_count + 1
+    #     else:
+    #         mas_week_count = 1
+    #     for i in range(5, 8):
+    #         new_date = x1 + timedelta(days=i)
+    #         new_datez = new_date.strftime("%d/%m/%Y")
+    #         new_day = new_date.strftime('%A')
+    #         current_dates.append(new_datez)
+    #         new_dayfromnow = x2 + i
+    #         temp_days.append(new_dayfromnow)
+    #         current_schedule = np.concatenate([current_schedule, temp_array], axis=0)
+    #         day_of_week_index[dict_elem_count] = str(new_day) + str(mas_week_count)
+    #         dict_elem_count = dict_elem_count + 1
+    # elif (datetime.strptime(current_dates[-1], '%d/%m/%Y').date()).strftime('%A') == 'Tuesday':
+    #     x1 = (datetime.strptime(current_dates[-1], '%d/%m/%Y').date())
+    #     x2 = temp_days[-1]
+    #     temp_array = np.zeros([1, 23, 44], dtype=np.int32)
+    #     dict_elem_count = len(current_dates)
+    #     mas_week_count = int(day_of_week_index[dict_elem_count - 1].split('y')[1])
+    #     for i in range(1, 4):
+    #         new_date = x1 + timedelta(days=i)
+    #         new_datez = new_date.strftime("%d/%m/%Y")
+    #         new_day = new_date.strftime('%A')
+    #         current_dates.append(new_datez)
+    #         new_dayfromnow = x2 + i
+    #         temp_days.append(new_dayfromnow)
+    #         current_schedule = np.concatenate([current_schedule, temp_array], axis=0)
+    #         day_of_week_index[dict_elem_count] = str(new_day) + str(mas_week_count)
+    #         dict_elem_count = dict_elem_count + 1
+    #     if mas_week_count != 5:
+    #         mas_week_count = mas_week_count + 1
+    #     else:
+    #         mas_week_count = 1
+    #     for i in range(6, 8):
+    #         new_date = x1 + timedelta(days=i)
+    #         new_datez = new_date.strftime("%d/%m/%Y")
+    #         new_day = new_date.strftime('%A')
+    #         current_dates.append(new_datez)
+    #         new_dayfromnow = x2 + i
+    #         temp_days.append(new_dayfromnow)
+    #         current_schedule = np.concatenate([current_schedule, temp_array], axis=0)
+    #         day_of_week_index[dict_elem_count] = str(new_day) + str(mas_week_count)
+    #         dict_elem_count = dict_elem_count + 1
+    # elif (datetime.strptime(current_dates[-1], '%d/%m/%Y').date()).strftime('%A') == 'Monday':
+    #     x1 = (datetime.strptime(current_dates[-1], '%d/%m/%Y').date())
+    #     x2 = temp_days[-1]
+    #     temp_array = np.zeros([1, 23, 44], dtype=np.int32)
+    #     dict_elem_count = len(current_dates)
+    #     mas_week_count = int(day_of_week_index[dict_elem_count - 1].split('y')[1])
+    #     for i in range(1, 5):
+    #         new_date = x1 + timedelta(days=i)
+    #         new_datez = new_date.strftime("%d/%m/%Y")
+    #         new_day = new_date.strftime('%A')
+    #         current_dates.append(new_datez)
+    #         new_dayfromnow = x2 + i
+    #         temp_days.append(new_dayfromnow)
+    #         current_schedule = np.concatenate([current_schedule, temp_array], axis=0)
+    #         day_of_week_index[dict_elem_count] = str(new_day) + str(mas_week_count)
+    #         dict_elem_count = dict_elem_count + 1
+    #     if mas_week_count != 5:
+    #         mas_week_count = mas_week_count + 1
+    #     else:
+    #         mas_week_count = 1
+    #     i = 7
+    #     new_date = x1 + timedelta(days=i)
+    #     new_datez = new_date.strftime("%d/%m/%Y")
+    #     new_day = new_date.strftime('%A')
+    #     current_dates.append(new_datez)
+    #     new_dayfromnow = x2 + i
+    #     temp_days.append(new_dayfromnow)
+    #     current_schedule = np.concatenate([current_schedule, temp_array], axis=0)
+    #     day_of_week_index[dict_elem_count] = str(new_day) + str(mas_week_count)
+    #     dict_elem_count = dict_elem_count + 1
 
     current_schedule_list.append(current_schedule)
     current_schedule_list.append(temp_days)
     current_schedule_list.append(current_dates)
     current_schedule_list.append(day_of_week_index)
 
-    return current_schedule_list
\ No newline at end of file
+    return current_schedule_list
